====================================
WeRoBot
====================================

.. image:: https://img.shields.io/travis/offu/WeRoBot/master.svg?maxAge=3600&label=macOS
    :target: https://travis-ci.org/offu/WeRoBot
.. image:: https://img.shields.io/appveyor/ci/whtsky/WeRoBot/master.svg?maxAge=3600&label=Windows
    :target: https://ci.appveyor.com/project/whtsky/WeRoBot
.. image:: https://img.shields.io/circleci/project/github/offu/WeRoBot.svg
    :target: https://circleci.com/gh/offu/WeRoBot
.. image:: https://codecov.io/gh/offu/WeRoBot/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/offu/WeRoBot
.. image:: https://img.shields.io/badge/QQ%20Group-283206829-brightgreen.svg?logo=data%3Aimage%2Fsvg%2Bxml%3Bbase64% %2BPC9zdmc%2B
    :target: https://jq.qq.com/?_wv=1027&k=449sXsV
.. image:: https://opencollective.com/werobot/backers/badge.svg
    :target: https://opencollective.com/werobot
    :alt: Backers on Open Collective
..  image:: https://opencollective.com/werobot/sponsors/badge.svg
    :target: https://opencollective.com/werobot
    :alt: Sponsors on Open Collective

WeRoBot 是一个微信公众号开发框架，采用MIT协议发布。

文档在这里： https://werobot.readthedocs.org/zh_CN/latest/

安装
========

推荐使用 pip 进行安装 ::

    pip install werobot

Hello World
=============

一个非常简单的 Hello World 微信公众号，会对收到的所有文本消息回复 Hello World ::

    import werobot

    robot = werobot.WeRoBot(token='tokenhere')

    @robot.text
    def hello_world():
        return 'Hello World!'

    robot.run()
    
Credits 
=======
Contributors
-----------------
Thank you to all the people who have already contributed. 
|occontributorimage|

Backers
-----------------
Thank you to all our backers! 
|ocbackerimage|

Sponsors
-----------------
Support this project by becoming a sponsor. Your logo will show up here with a link to your website. `become_sponsor`_

|ocsponsor0| |ocsponsor1| |ocsponsor2|

.. |ocbackerimage| image:: https://opencollective.com/werobot/backers.svg?width=890
    :target: https://opencollective.com/werobot
    :alt: Backers on Open Collective
.. |occontributorimage| image:: https://opencollective.com/werobot/contributors.svg?width=890&button=false
    :target: https://opencollective.com/werobot
    :alt: Repo Contributors

.. _become_sponsor: https://opencollective.com/werobot#sponsor

.. |ocsponsor0| image:: https://opencollective.com/werobot/sponsor/0/avatar.svg
    :target: https://opencollective.com/werobot/sponsor/0/website
    :alt: Sponsor
.. |ocsponsor1| image:: https://opencollective.com/werobot/sponsor/1/avatar.svg
    :target: https://opencollective.com/werobot/sponsor/1/website
    :alt: Sponsor
.. |ocsponsor2| image:: https://opencollective.com/werobot/sponsor/2/avatar.svg
    :target: https://opencollective.com/werobot/sponsor/2/website
    :alt: Sponsor

